@@ -3,6 +3,8 @@ makeProblem = function(id, static, dynamic) {
              "Problem")
 }
 
+#FIXME the seed mechansim is described slighlty wrong! fix! random seed!
+
 #' Add a problem to registry.
 #'
 #' Add a algorithm to problem and stores it on disk.
@@ -40,7 +42,7 @@ makeProblem = function(id, static, dynamic) {
 #' @aliases Problem
 #' @export
 addProblem = function(reg, id, static=NULL, dynamic=NULL, seed=NULL, overwrite=FALSE)  {
-  checkArg(reg, "ExperimentRegistry")
+  checkExperimentRegistry(reg, strict=TRUE)
   checkArg(id, cl = "character", len=1L, na.ok = FALSE)
   BatchJobs:::checkIdValid(id)
   if (!is.null(seed)) {
