@@ -24,7 +24,7 @@
 #' @return [\code{integer}]. Ids for experiments which match the query.
 #' @export
 findExperiments = function(reg, ids, prob.pattern, prob.pars, algo.pattern, algo.pars, repls, match.substring=TRUE) {
-  checkArg(reg, cl="ExperimentRegistry")
+  checkExperimentRegistry(reg, strict=TRUE)
   BatchJobs:::syncRegistry(reg)
   if (!missing(prob.pattern))
     checkArg(prob.pattern, "character", len=1L, na.ok=FALSE)
