@@ -7,7 +7,7 @@
 #' @return Dynamic part of problem.
 #' @export
 generateProblemInstance = function(reg, id) {
-  checkArg(reg, "ExperimentRegistry")
+  checkExperimentRegistry(reg, strict=TRUE)
   id = BatchJobs:::checkId(reg, id)
 
   dynamic = getDynamicLazy(reg, getJob(reg, id, check.id=FALSE))
